#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_skin.interfaces.configuration import IConfiguration, IBackOfficeConfiguration
from pyams_utils.interfaces.site import ISiteRoot as ISiteRootBase

# import packages
from pyams_security.schema import PrincipalsSet, Principal
from zope.interface import Interface, Attribute

from pyams_content import _


class ISiteRoot(ISiteRootBase):
    """Main site root interface"""


class ISiteRootRoles(Interface):
    """Main site roles"""

    managers = PrincipalsSet(title=_("Site managers"),
                             role_id='system.Manager',
                             required=False)

    webmasters = PrincipalsSet(title=_("Webmasters"),
                               role_id='pyams.Webmaster',
                               required=False)

    templates_managers = PrincipalsSet(title=_("Templates managers"),
                                       role_id='pyams.TemplatesManager',
                                       required=False)

    operators = Principal(title=_("Operators group"),
                          description=_("Name of group containing all roles owners"),
                          role_id='pyams.Operator',
                          required=False)


class ISiteRootConfiguration(IConfiguration):
    """Site root configuration interface"""


class ISiteRootToolsConfiguration(Interface):
    """Site root tools configuration interface"""

    tables_name = Attribute("References tables manager name")

    pictograms_table_name = Attribute("Pictograms reference table name")

    tools_name = Attribute("Tools name")

    views_tool_name = Attribute("Views tool name")
    forms_tool_name = Attribute("Forms tool name")
    imagemaps_tool_name = Attribute("Image maps tool name")
    logos_tool_name = Attribute("Logos tool name")
    news_tool_name = Attribute("News tool name")


class ISiteRootBackOfficeConfiguration(IBackOfficeConfiguration):
    """Site root back-office configuration interface"""
