#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.component.paragraph.interfaces import IParagraphContainerTarget, IParagraphContainer, \
    IParagraphRenderer
from pyams_content.component.paragraph.zmi.interfaces import IParagraphInnerEditor, IParagraphContainerView
from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION
from pyams_content.shared.common.interfaces import IWfSharedContent
from pyams_content.shared.imagemap.interfaces import IImageMapParagraph, IMAGEMAP_PARAGRAPH_TYPE
from pyams_form.interfaces.form import IInnerForm, IEditFormButtons, IWidgetsSuffixViewletsManager
from pyams_i18n.interfaces import II18n
from pyams_skin.interfaces.viewlet import IToolbarAddingMenu
from pyams_skin.layer import IPyAMSLayer
from z3c.form.interfaces import INPUT_MODE

# import packages
from pyams_content.component.paragraph.zmi import BaseParagraphAJAXAddForm, BaseParagraphAJAXEditForm, \
    BaseParagraphAddMenu, BaseParagraphPropertiesEditForm
from pyams_content.shared.imagemap.paragraph import ImageMapParagraph
from pyams_pagelet.pagelet import pagelet_config
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.traversing import get_parent
from pyams_viewlet.viewlet import viewlet_config, BaseContentProvider, Viewlet
from pyams_zmi.form import AdminDialogAddForm
from pyramid.view import view_config
from z3c.form import field, button
from zope.interface import implementer

from pyams_content import _


@viewlet_config(name='add-imagemap-paragraph.menu', context=IParagraphContainerTarget, view=IParagraphContainerView,
                layer=IPyAMSLayer, manager=IToolbarAddingMenu, weight=520)
class ImagemapParagraphAddMenu(BaseParagraphAddMenu):
    """Image map paragraph add menu"""

    label = _("Image map...")
    label_css_class = 'fa fa-fw fa-location-arrow'
    url = 'add-imagemap-paragraph.html'
    paragraph_type = IMAGEMAP_PARAGRAPH_TYPE


@pagelet_config(name='add-imagemap-paragraph.html', context=IParagraphContainerTarget, layer=IPyAMSLayer,
                permission=MANAGE_CONTENT_PERMISSION)
class ImagemapParagraphAddForm(AdminDialogAddForm):
    """Image map paragraph add form"""

    legend = _("Add new image map")
    icon_css_class = 'fa fa-fw fa-location-arrow'

    fields = field.Fields(IImageMapParagraph).omit('__parent__', '__name__', 'visible')
    ajax_handler = 'add-imagemap-paragraph.json'
    edit_permission = MANAGE_CONTENT_PERMISSION

    def create(self, data):
        return ImageMapParagraph()

    def add(self, object):
        IParagraphContainer(self.context).append(object)


@view_config(name='add-imagemap-paragraph.json', context=IParagraphContainerTarget, request_type=IPyAMSLayer,
             permission=MANAGE_CONTENT_PERMISSION, renderer='json', xhr=True)
class ImagemapParagraphAJAXAddForm(BaseParagraphAJAXAddForm, ImagemapParagraphAddForm):
    """Image map paragraph add form, JSON renderer"""


@pagelet_config(name='properties.html', context=IImageMapParagraph, layer=IPyAMSLayer,
                permission=MANAGE_CONTENT_PERMISSION)
class ImagemapParagraphPropertiesEditForm(BaseParagraphPropertiesEditForm):
    """Image map paragraph edit form"""

    @property
    def title(self):
        content = get_parent(self.context, IWfSharedContent)
        return II18n(content).query_attribute('title', request=self.request)

    legend = _("Edit paragraph properties")
    icon_css_class = 'fa fa-fw fa-location-arrow'

    fields = field.Fields(IImageMapParagraph).omit('__parent__', '__name__', 'visible')
    ajax_handler = 'properties.json'
    edit_permission = MANAGE_CONTENT_PERMISSION


@view_config(name='properties.json', context=IImageMapParagraph, request_type=IPyAMSLayer,
             permission=MANAGE_CONTENT_PERMISSION, renderer='json', xhr=True)
class ImagemapParagrahPropertiesAJAXEditForm(BaseParagraphAJAXEditForm, ImagemapParagraphPropertiesEditForm):
    """Image map properties edit form, JSON renderer"""


@adapter_config(context=(IImageMapParagraph, IPyAMSLayer), provides=IParagraphInnerEditor)
@implementer(IInnerForm)
class ImagemapParagraphInnerEditForm(ImagemapParagraphPropertiesEditForm):
    """Image map properties inner edit form"""

    legend = None
    ajax_handler = 'inner-properties.json'

    @property
    def buttons(self):
        if self.mode == INPUT_MODE:
            return button.Buttons(IEditFormButtons)
        else:
            return button.Buttons()


@view_config(name='inner-properties.json', context=IImageMapParagraph, request_type=IPyAMSLayer,
             permission=MANAGE_CONTENT_PERMISSION, renderer='json', xhr=True)
class ImagemapParagraphInnerAJAXEditForm(BaseParagraphAJAXEditForm, ImagemapParagraphInnerEditForm):
    """Image map paragraph properties inner edit form, JSON rendener"""

    def get_ajax_output(self, changes):
        output = super(ImagemapParagraphInnerAJAXEditForm, self).get_ajax_output(changes)
        if 'reference' in changes.get(IImageMapParagraph, ()):
            form = ImagemapParagraphInnerEditForm(self.context, self.request)
            form.update()
            content = form.getContent()
            output.setdefault('events', []).append({
                'event': 'myams.refresh',
                'options': {
                    'object_id': '{0}_{1}_{2}'.format(
                        content.__class__.__name__,
                        getattr(content, '__name__', 'noname').replace('++', ''),
                        form.id),
                    'content': form.render()
                }
            })
        return output


@viewlet_config(name='imagemap-preview', context=IImageMapParagraph, layer=IPyAMSLayer,
                view=ImagemapParagraphInnerEditForm, manager=IWidgetsSuffixViewletsManager, weight=1)
@template_config(template='templates/imagemap-preview.pt', layer=IPyAMSLayer)
class ImagemapParagraphPreviewWidgetsSuffix(Viewlet):
    """Image map paragraph preview widgets suffix"""


#
# Image map paragraph renderer
#

@adapter_config(context=(IImageMapParagraph, IPyAMSLayer), provides=IParagraphRenderer)
@template_config(template='templates/paragraph-render.pt', layer=IPyAMSLayer)
class ImagemapParagraphRenderer(BaseContentProvider):
    """Image map paragraph renderer"""

    language = None

    def update(self):
        i18n = II18n(self.context)
        if self.language:
            setattr(self, 'title', i18n.get_attribute('title', self.language, request=self.request))
        else:
            setattr(self, 'title', i18n.query_attribute('title', request=self.request))

    def get_item_info(self, item):
        return IAssociationInfo(item, None)
