#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from hypatia.interfaces import ICatalog
from pyams_content.shared.common.interfaces import IBaseSharedTool, ISharedSite
from pyams_content.skin.zmi.interfaces import IUserAddingsMenuLabel
from pyams_i18n.interfaces import II18n
from pyams_skin.interfaces.viewlet import ITopLinksViewletManager
from pyams_zmi.layer import IAdminLayer

# import packages
from hypatia.catalog import CatalogQuery
from hypatia.query import Any, And, Or, NotEq
from pyams_catalog.query import CatalogResultSet
from pyams_skin.viewlet.toplinks import TopLinksViewlet, TopLinksMenu
from pyams_template.template import template_config
from pyams_utils.list import unique
from pyams_utils.registry import get_local_registry, get_utility
from pyams_utils.url import absolute_url
from pyams_viewlet.viewlet import viewlet_config
from pyramid.threadlocal import get_current_registry

from pyams_content import _


@viewlet_config(name='shared-sites.menu', layer=IAdminLayer, manager=ITopLinksViewletManager, weight=20)
class SharedSitesMenu(TopLinksViewlet):
    """Shared sites menu"""

    label = ''
    css_class = 'top-menu bordered margin-top-10'
    dropdown_label = _("Shared sites")

    def update(self):
        super(SharedSitesMenu, self).update()
        registry = get_local_registry()
        for site in sorted(registry.getAllUtilitiesRegisteredFor(ISharedSite),
                           key=lambda x: II18n(x).query_attribute('title', request=self.request) or ''):
            menu = TopLinksMenu(self.context, self.request, self.__parent__, self)
            menu.label = II18n(site).query_attribute('title', request=self.request) or site.__name__
            menu.url = absolute_url(site, self.request, 'admin#dashboard.html')
            self.viewlets.append(menu)


@viewlet_config(name='shared-tools.menu', layer=IAdminLayer, manager=ITopLinksViewletManager, weight=30)
class SharedToolsMenu(TopLinksViewlet):
    """Shared tools menu"""

    label = ''
    css_class = 'top-menu bordered margin-top-10'
    dropdown_label = _("Shared contents")

    def update(self):
        super(SharedToolsMenu, self).update()
        registry = get_local_registry()
        for tool in sorted(registry.getAllUtilitiesRegisteredFor(IBaseSharedTool),
                           key=lambda x: II18n(x).query_attribute('title', request=self.request) or ''):
            if ISharedSite.providedBy(tool):
                continue
            menu = TopLinksMenu(self.context, self.request, self.__parent__, self)
            menu.label = II18n(tool).query_attribute('title', request=self.request) or tool.__name__
            menu.url = absolute_url(tool, self.request, 'admin#dashboard.html')
            self.viewlets.append(menu)


@viewlet_config(name='user-roles.menu', layer=IAdminLayer, manager=ITopLinksViewletManager, weight=90)
class UserRolesMenu(TopLinksViewlet):
    """User roles menu"""

    label = ''
    css_class = 'top-menu bordered margin-top-10'
    dropdown_label = _("My roles")

    def update(self):
        super(UserRolesMenu, self).update()
        catalog = get_utility(ICatalog)
        params = And(Or(Any(catalog['role:contributor'], {self.request.principal.id}),
                        Any(catalog['role:manager'], {self.request.principal.id}),
                        Any(catalog['role:pilot'], {self.request.principal.id})),
                     NotEq(catalog['content_type'], None))
        for tool in sorted(unique(CatalogResultSet(CatalogQuery(catalog).query(params))),
                           key=lambda x: II18n(x).query_attribute('title', request=self.request) or ''):
            menu = TopLinksMenu(self.context, self.request, self.__parent__, self)
            menu.label = II18n(tool).query_attribute('title', request=self.request) or tool.__name__
            menu.url = absolute_url(tool, self.request, 'admin#dashboard.html')
            self.viewlets.append(menu)


@viewlet_config(name='user-addings.menu', layer=IAdminLayer, manager=ITopLinksViewletManager, weight=95)
@template_config(template='templates/user-addings.pt', layer=IAdminLayer)
class UserAddingsMenu(TopLinksViewlet):
    """User addings menu"""

    label = ''
    css_class = 'top-menu margin-top-5-neg'
    dropdown_label = ''

    def update(self):
        super(UserAddingsMenu, self).update()
        catalog = get_utility(ICatalog)
        registry = get_current_registry()
        params = And(Any(catalog['role:contributor'], {self.request.principal.id}),
                     NotEq(catalog['content_type'], None))
        for tool in sorted(unique(CatalogResultSet(CatalogQuery(catalog).query(params))),
                           key=lambda x: II18n(x).query_attribute('title', request=self.request) or ''):
            menu = TopLinksMenu(self.context, self.request, self.__parent__, self)
            adapter = registry.queryMultiAdapter((tool, self.request), IUserAddingsMenuLabel)
            if adapter is None:
                menu.label = self.request.localizer.translate(tool.shared_content_factory.content_class.content_name)
            else:
                menu.label = adapter.label
            menu.url = absolute_url(tool, self.request, 'add-shared-content.html')
            menu.data = {'data-toggle': 'modal'}
            self.viewlets.append(menu)
